#include "watchdog.hpp"
#include <avr/wdt.h>

using namespace Devices::Mcu;


constexpr static int TimeoutToInt(WatchDog::Timeout const timeout)
{
    switch (timeout)
    {
        case WatchDog::Timeout::_8s:
            return WDTO_8S;

        case WatchDog::Timeout::_4s:
            return WDTO_4S;

        case WatchDog::Timeout::_2s:
            return WDTO_2S;

        case WatchDog::Timeout::_1s:
            return WDTO_1S;

        case WatchDog::Timeout::_500ms:
            return WDTO_500MS;

        case WatchDog::Timeout::_250ms:
            return WDTO_250MS;

        case WatchDog::Timeout::_120ms:
            return WDTO_120MS;

        case WatchDog::Timeout::_60ms:
            return WDTO_60MS;

        case WatchDog::Timeout::_30ms:
            return WDTO_30MS;

        case WatchDog::Timeout::_15ms:
        default:
            return WDTO_15MS;
    }
}


void WatchDog::AlwaysOn::Init()
{
    MCUSR = 0;
    AlwaysOn::Reset();
}


void WatchDog::AlwaysOn::Enable(Timeout const timeout)
{
    wdt_enable(TimeoutToInt(timeout));
}


void WatchDog::AlwaysOn::Disable()
{
    wdt_disable();
}


void WatchDog::AlwaysOn::Reset()
{
    wdt_reset();
}